@@ -4,7 +4,7 @@ from pkg_resources import get_distribution, DistributionNotFound
 import os.path
 
 try:
-    _dist = get_distribution('foobar')
+    _dist = get_distribution('djehuty')
     if not __file__.startswith(os.path.join(_dist.location, 'djehuty')):
         raise DistributionNotFound
 except DistributionNotFound:
